@@ -15,6 +15,17 @@ var nats_8h =
     [ "JSLastSequence", "nats_8h.html#ae18fb15ea8130a650e904e5153eb30d5", null ],
     [ "JSTimeStamp", "nats_8h.html#a5525cb01f8b0aec73cb13f3276449e0e", null ],
     [ "JSSubject", "nats_8h.html#a3776aa9985557f0c6e382b01d2e3f602", null ],
+    [ "MICRO_API_PREFIX", "group__micro_constants.html#ga2ad15244b5f6541d0d30207bb71e2667", null ],
+    [ "MICRO_INFO_RESPONSE_TYPE", "group__micro_constants.html#ga50e5fc6d460c30bc851dc5d45e938208", null ],
+    [ "MICRO_INFO_VERB", "group__micro_constants.html#gaab340591dc3b52411f35f23c945b25f8", null ],
+    [ "MICRO_PING_RESPONSE_TYPE", "group__micro_constants.html#ga71f630d0974d85530e7d04a3718dfafc", null ],
+    [ "MICRO_PING_VERB", "group__micro_constants.html#ga27bccc83509da632aec126d97c320fbb", null ],
+    [ "MICRO_STATS_RESPONSE_TYPE", "group__micro_constants.html#gae1ba7c2a70df4daaeaba5fbebe9c0904", null ],
+    [ "MICRO_STATS_VERB", "group__micro_constants.html#ga4284e07f1991b9807a1dadea4b0f6a67", null ],
+    [ "MICRO_STATUS_HDR", "group__micro_constants.html#ga4f5f6337514aa735d486e9397bd9d0c0", null ],
+    [ "MICRO_ERROR_HDR", "group__micro_constants.html#ga8f052c5047750ee329d2fb496d977bad", null ],
+    [ "MICRO_ERROR_CODE_HDR", "group__micro_constants.html#ga3821f13d4cff7a22f7c8c21181847b44", null ],
+    [ "microError_Ignore", "group__micro_error_functions.html#ga7d7cf243a0d24ff38fbaf6afdfb461cd", null ],
     [ "natsSock", "nats_8h.html#af798865ac824e5959987de0fe8d07383", null ],
     [ "natsConnection", "group__types_group.html#gaf88dca0a18efb5c5e994d265a9f04aec", null ],
     [ "natsStatistics", "group__types_group.html#ga57a4b8c7109e2773878655722ce028aa", null ],
@@ -23,12 +34,15 @@ var nats_8h =
     [ "natsOptions", "group__types_group.html#gabcc48b40a81fe302188f4ee06ea9c54e", null ],
     [ "natsInbox", "group__types_group.html#ga206c3d4d6f4f6f96fd2cae53a3df31c1", null ],
     [ "natsMsgList", "group__types_group.html#gafd5523161ec3783e79719cb9a9a66b5b", null ],
+    [ "natsMetadata", "group__types_group.html#ga3b454f3c6ac697a3cdc5bdd3c9ece12b", null ],
     [ "jsCtx", "group__types_group.html#gaaf12cdd24c6cc23a57c20466c92ff8c1", null ],
     [ "jsPubOptions", "group__types_group.html#ga7bbea3575d35dcdbfc9b766b04269eb7", null ],
     [ "jsPlacement", "group__types_group.html#ga49d1138fac9da8b85d00a367081e91c9", null ],
     [ "jsExternalStream", "group__types_group.html#gaef6601477f6456bebc229f7f38982a6c", null ],
     [ "jsStreamSource", "group__types_group.html#gab4c43c87d81917aab748a50eee028449", null ],
     [ "jsRePublish", "group__types_group.html#gab991313d33ce270a882e4d0756c138f6", null ],
+    [ "jsSubjectTransformConfig", "group__types_group.html#gac3148248f38749f6ba70471b7a6b96e1", null ],
+    [ "jsStreamConsumerLimits", "group__types_group.html#gadb76a02c18655461dbd3ee266502338c", null ],
     [ "jsStreamConfig", "group__types_group.html#ga26fd6a73df327ca3c271e46ddefc8acf", null ],
     [ "jsLostStreamData", "group__types_group.html#gaf80828510450faf84bbf456e94f5b784", null ],
     [ "jsStreamStateSubject", "group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa", null ],
@@ -90,6 +104,22 @@ var nats_8h =
     [ "stanPubAckHandler", "group__callbacks_group.html#gad5d6a685731b3bf635995b7375af4d18", null ],
     [ "stanMsgHandler", "group__callbacks_group.html#gaf7456e37fa14f1834d9048d3789e9409", null ],
     [ "stanConnectionLostHandler", "group__callbacks_group.html#gac34092f6c698374f86ad349302bdd55c", null ],
+    [ "microClient", "group__micro_types.html#ga22c8eebaa1ca15ba0834b89cc1081130", null ],
+    [ "microClientConfig", "group__micro_types.html#ga550430b08d2e071e3901c6d720f4a039", null ],
+    [ "microEndpoint", "group__micro_types.html#gaea03a1fb23faec1d7919054b27acfbc3", null ],
+    [ "microEndpointConfig", "group__micro_types.html#ga7718d2f2c911e4cf677788f4ffe048cd", null ],
+    [ "microEndpointInfo", "group__micro_types.html#gadd4fcc67087b4d5f42015a7269cb6496", null ],
+    [ "microEndpointStats", "group__micro_types.html#ga0a429a5ecfff69b212a3ba9abebcba53", null ],
+    [ "microError", "group__micro_types.html#ga41ae4121cf2f8e326369bbc2e44e20d7", null ],
+    [ "microGroup", "group__micro_types.html#ga2681ea21e9f5f6681b972bbb67e32133", null ],
+    [ "microRequest", "group__micro_types.html#ga417ace5dc09fe8a2f6fd3882302a37c4", null ],
+    [ "microService", "group__micro_types.html#gaf6f5aef8773b70746e84c100c2b19b28", null ],
+    [ "microServiceConfig", "group__micro_types.html#ga1e46c0657cf42e83b366d224f380fb55", null ],
+    [ "microServiceInfo", "group__micro_types.html#ga033705d0404de94efb7a6444c6e91743", null ],
+    [ "microServiceStats", "group__micro_types.html#gaf832de937edc57bcc3af5e1456b3760c", null ],
+    [ "microRequestHandler", "group__micro_callbacks.html#gab465a9b31672c63738e8f6b0a61c2e90", null ],
+    [ "microErrorHandler", "group__micro_callbacks.html#ga7a40fbbb9b1102f0a7679f9dfcf6c0d6", null ],
+    [ "microDoneHandler", "group__micro_callbacks.html#gae0341a98388ffd1094472d2ced36d840", null ],
     [ "jsRetentionPolicy", "group__types_group.html#ga410f8fb053efa02b2ca1de0c02fa4b6d", [
       [ "js_LimitsPolicy", "group__types_group.html#gga410f8fb053efa02b2ca1de0c02fa4b6da6a2aa02f32acec6526d81f6e974e690f", null ],
       [ "js_InterestPolicy", "group__types_group.html#gga410f8fb053efa02b2ca1de0c02fa4b6dae874de4a787cfbec4c6d0eb1a3f05ebd", null ],
@@ -103,6 +133,10 @@ var nats_8h =
       [ "js_FileStorage", "group__types_group.html#gga1802a53c79e667f093bba033b16adc98a1d9dad1854cf374b22e3688b98284dec", null ],
       [ "js_MemoryStorage", "group__types_group.html#gga1802a53c79e667f093bba033b16adc98a428ed10448726ad01c1db77a7f748314", null ]
     ] ],
+    [ "jsStorageCompression", "group__types_group.html#ga10d2999dc673ed95e131e6ce5181f720", [
+      [ "js_StorageCompressionNone", "group__types_group.html#gga10d2999dc673ed95e131e6ce5181f720a97bd071285006dc90dc4600a25f85e89", null ],
+      [ "js_StorageCompressionS2", "group__types_group.html#gga10d2999dc673ed95e131e6ce5181f720afab4e3a974823f4438292b2405349d4a", null ]
+    ] ],
     [ "jsDeliverPolicy", "group__types_group.html#ga117ed2c35f89ef3144540ed9cbadc818", [
       [ "js_DeliverAll", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818ac692ba1363103768ac4bb58695549758", null ],
       [ "js_DeliverLast", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818abbd81d6c4e0f17f30e2186f1335e991d", null ],
@@ -192,11 +226,13 @@ var nats_8h =
     [ "natsOptions_SetRetryOnFailedConnect", "group__opts_group.html#ga20946800d024b7089e73d63454d1c19f", null ],
     [ "natsOptions_SetUserCredentialsCallbacks", "group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515", null ],
     [ "natsOptions_SetUserCredentialsFromFiles", "group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e", null ],
+    [ "natsOptions_SetUserCredentialsFromMemory", "group__opts_group.html#ga5d3d4d1269dd289f93c56b8a1ddccd43", null ],
     [ "natsOptions_SetNKey", "group__opts_group.html#ga0290eac4665569c850468d9f00e246a0", null ],
     [ "natsOptions_SetNKeyFromSeed", "group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e", null ],
     [ "natsOptions_SetWriteDeadline", "group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218", null ],
     [ "natsOptions_DisableNoResponders", "group__opts_group.html#ga192465163abb87ad48a843b45cdf9984", null ],
     [ "natsOptions_SetCustomInboxPrefix", "group__opts_group.html#gac5173473a731a4a36d15346fedddf91f", null ],
+    [ "natsOptions_SetMessageBufferPadding", "group__opts_group.html#ga5acd292cdaeb63d3d7bd9bbc05513c8f", null ],
     [ "natsOptions_Destroy", "group__opts_group.html#ga93d8068cd6fff53b7f8e1c403db45eb9", null ],
     [ "stanConnOptions_Create", "group__stan_conn_opts_group.html#gaff52a1ce90253b4bdbb0005fca4f71b6", null ],
     [ "stanConnOptions_SetURL", "group__stan_conn_opts_group.html#ga3c6d511fc1e1febcdf5344960de5a0b3", null ],
@@ -427,5 +463,49 @@ var nats_8h =
     [ "kvStatus_TTL", "group__kv_status.html#gaa747ad0a6182ec7a47fb47018c33d1c1", null ],
     [ "kvStatus_Replicas", "group__kv_status.html#ga86b114f4dac9f06df86101f84bd497b2", null ],
     [ "kvStatus_Bytes", "group__kv_status.html#ga6db13a3b26c7c17633623da5f27978ff", null ],
-    [ "kvStatus_Destroy", "group__kv_status.html#ga5eb3d824c1873af705beee4798246a08", null ]
+    [ "kvStatus_Destroy", "group__kv_status.html#ga5eb3d824c1873af705beee4798246a08", null ],
+    [ "micro_AddService", "group__micro_service_functions.html#ga2986a9751147b6f77064b5739635c2c1", null ],
+    [ "microService_AddEndpoint", "group__micro_service_functions.html#gadcab5687b72ec24ef7ae647ea844ebc7", null ],
+    [ "microService_AddGroup", "group__micro_service_functions.html#ga578c9af27fda603dc84e7ad736685bd8", null ],
+    [ "microService_Destroy", "group__micro_service_functions.html#ga32ff6b2fb38eafb4df8e6b1039ee5984", null ],
+    [ "microService_GetConnection", "group__micro_service_functions.html#ga20bb55e101c42a3b7172ea055b3ea04f", null ],
+    [ "microService_GetInfo", "group__micro_service_functions.html#gae7f5d4bde8ac12bde5ad48cebfad9e25", null ],
+    [ "microService_GetState", "group__micro_service_functions.html#gaf58eddc84ef124c80a86d380075ef226", null ],
+    [ "microService_GetStats", "group__micro_service_functions.html#ga19b3b7126a1e2472a4970fc16b2f9fb4", null ],
+    [ "microService_IsStopped", "group__micro_service_functions.html#gac829b81893f09b1ed7c401147ed6b0c0", null ],
+    [ "microService_Run", "group__micro_service_functions.html#gaecde4e29e2b963e73fe4a8ff2fce064a", null ],
+    [ "microService_Stop", "group__micro_service_functions.html#ga35de7172dac67472ac3890bc955b9b42", null ],
+    [ "microGroup_AddGroup", "group__micro_group_functions.html#ga0bdc873f98dd1cb6c88b5c14974d74a0", null ],
+    [ "microGroup_AddEndpoint", "group__micro_group_functions.html#gabc9641ad7ee7775c388c864f2ffa6883", null ],
+    [ "microRequest_AddHeader", "group__micro_request_functions.html#ga6a6fa30291301abf54e25a24fde7e293", null ],
+    [ "microRequest_DeleteHeader", "group__micro_request_functions.html#gad50a68e2193da36d7b477a34f488840c", null ],
+    [ "microRequest_GetConnection", "group__micro_request_functions.html#ga6cf9c55a05fe1234ef264c25ca8294b3", null ],
+    [ "microRequest_GetData", "group__micro_request_functions.html#ga695cf95ff0f596affecbd3954fd498cf", null ],
+    [ "microRequest_GetDataLength", "group__micro_request_functions.html#ga3fd1eef10afd445f517d73f32c9d4fd0", null ],
+    [ "microRequest_GetEndpointState", "group__micro_request_functions.html#gab999f2b9972c4339f6f78f491dfc6f3b", null ],
+    [ "microRequest_GetHeaderKeys", "group__micro_request_functions.html#gab78f9e653c13c8bbbbaa74d50dd34aa4", null ],
+    [ "microRequest_GetHeaderValue", "group__micro_request_functions.html#gad28fb0245a4c6d3218e4d233c141d3ce", null ],
+    [ "microRequest_GetHeaderValues", "group__micro_request_functions.html#gad73789e910856e6d3ece0ea95f1c8a54", null ],
+    [ "microRequest_GetMsg", "group__micro_request_functions.html#ga764c2ebab8816c4706d6e49e5cbe8320", null ],
+    [ "microRequest_GetReply", "group__micro_request_functions.html#gae87e12447ebc9864d38268a15c370182", null ],
+    [ "microRequest_GetService", "group__micro_request_functions.html#ga285974d2b6bc4b1369d9a9aa495e8119", null ],
+    [ "microRequest_GetServiceState", "group__micro_request_functions.html#ga8947795096eb225b16af422026627efa", null ],
+    [ "microRequest_GetSubject", "group__micro_request_functions.html#ga6727593cc380ad418e1d45d232ffea5e", null ],
+    [ "microRequest_Respond", "group__micro_request_functions.html#ga9c50e895154b151d3c9dadd3502b80f9", null ],
+    [ "microRequest_RespondError", "group__micro_request_functions.html#ga402e8ccd0602a27d333d50088f6a92a3", null ],
+    [ "microRequest_RespondCustom", "group__micro_request_functions.html#gae62bab929e8835da250870cfde2f22b2", null ],
+    [ "microRequest_SetHeader", "group__micro_request_functions.html#gab94d97619daf42590d7e6c6bd758b9ab", null ],
+    [ "micro_Errorf", "group__micro_error_functions.html#ga7732a5a63c3b452f8d78f4e41e726fe1", null ],
+    [ "micro_ErrorfCode", "group__micro_error_functions.html#ga91dd255ecb0fc97fddb0b8abe4a3fc4c", null ],
+    [ "micro_ErrorFromStatus", "group__micro_error_functions.html#gac557c5b7b565746d8c5521c726842641", null ],
+    [ "microError_Code", "group__micro_error_functions.html#ga69edae8121c8a5a093c76ee2662bae54", null ],
+    [ "microError_Destroy", "group__micro_error_functions.html#ga1bf0dc7e647ffd431bdca222d9246f07", null ],
+    [ "microError_Status", "group__micro_error_functions.html#ga2648fe981670c5394bd058128ef6478c", null ],
+    [ "microError_String", "group__micro_error_functions.html#ga9694838e69616612ef98afe7a45cb58d", null ],
+    [ "microError_Wrapf", "group__micro_error_functions.html#gad43118a9e9e48aefbde3b21c4bd9d36f", null ],
+    [ "micro_NewClient", "group__micro_client_functions.html#ga191be60c4f9bb88f83f73b5ce4e5e0bd", null ],
+    [ "microClient_Destroy", "group__micro_client_functions.html#ga62a528edb67328bd7c478b6338656e1a", null ],
+    [ "microClient_DoRequest", "group__micro_client_functions.html#gac3be6a03f5846ac1bb06f091bea36a99", null ],
+    [ "microServiceInfo_Destroy", "group__micro_cleanup_functions.html#ga9b4756ed693ce4fc0f06375aa0d3d54c", null ],
+    [ "microServiceStats_Destroy", "group__micro_cleanup_functions.html#gaabcbf8378e6221eea78493a26576c8ce", null ]
 ];
\ No newline at end of file
