@@ -25,14 +25,9 @@
 var NAVTREE =
 [
   [ "NATS C Client with JetStream and Streaming support", "index.html", [
-    [ "NATS C client.", "index.html", [
-      [ "Introduction", "index.html#intro_sec", null ],
-      [ "Installation", "index.html#install_sec", null ],
-      [ "Frequently Asked Questions", "index.html#faq_sec", null ],
-      [ "Other Documentation", "index.html#other_doc_section", null ]
-    ] ],
+    [ "NATS C client.", "index.html", "index" ],
     [ "Deprecated List", "deprecated.html", null ],
-    [ "Modules", "modules.html", "modules" ],
+    [ "Topics", "topics.html", "topics" ],
     [ "Classes", "annotated.html", [
       [ "Class List", "annotated.html", "annotated_dup" ],
       [ "Class Index", "classes.html", null ],
@@ -58,10 +53,10 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"group__libevent_functions.html#ga30c00f21a5251ee9fde09c1f2b429cd2",
-"group__types_group.html#gga7f88b7d482488398074f9d1419a9b8c2a99d7f2d740af26c340c0a4e2b72fb6ab",
-"structjs_consumer_config.html#a351b388a36ccb7978e6e85a6f4fc0816",
-"structkv_purge_options.html#a245c2def0f3aabe617219772cf7680a8"
+"group__kv_watcher.html#ga562c216a0199c30455af4c2da46000e5",
+"group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20",
+"status_8h.html#a10731415ffcd3e2330df10c4d5fd3d70ae7479c265d0e8cace4ab19a59cfcbbbb",
+"structjs_stream_config.html#a7338c82c8cbfcd5f4bfb7ad34b1d8395"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
