@@ -6,8 +6,8 @@ var NAVTREEINDEX0 =
 "dir_085924db4bed469054a9264cf96b0d5e.html":[4,0,0,0],
 "dir_68267d1309a1af8e8297ef4c3efbcdba.html":[4,0,0],
 "files.html":[4,0],
-"functions.html":[3,2,0],
 "functions.html":[3,2,0,0],
+"functions.html":[3,2,0],
 "functions_b.html":[3,2,0,1],
 "functions_c.html":[3,2,0,2],
 "functions_d.html":[3,2,0,3],
@@ -25,6 +25,7 @@ var NAVTREEINDEX0 =
 "functions_r.html":[3,2,0,15],
 "functions_s.html":[3,2,0,16],
 "functions_t.html":[3,2,0,17],
+"functions_v.html":[3,2,0,18],
 "functions_vars.html":[3,2,1],
 "functions_vars.html":[3,2,1,0],
 "functions_vars_b.html":[3,2,1,1],
@@ -44,8 +45,9 @@ var NAVTREEINDEX0 =
 "functions_vars_r.html":[3,2,1,15],
 "functions_vars_s.html":[3,2,1,16],
 "functions_vars_t.html":[3,2,1,17],
-"functions_vars_w.html":[3,2,1,18],
-"functions_w.html":[3,2,0,18],
+"functions_vars_v.html":[3,2,1,18],
+"functions_vars_w.html":[3,2,1,19],
+"functions_w.html":[3,2,0,19],
 "globals.html":[4,1,0],
 "globals.html":[4,1,0,0],
 "globals_defs.html":[4,1,5],
@@ -54,11 +56,13 @@ var NAVTREEINDEX0 =
 "globals_func.html":[4,1,1],
 "globals_func.html":[4,1,1,0],
 "globals_func_k.html":[4,1,1,1],
-"globals_func_n.html":[4,1,1,2],
-"globals_func_s.html":[4,1,1,3],
+"globals_func_m.html":[4,1,1,2],
+"globals_func_n.html":[4,1,1,3],
+"globals_func_s.html":[4,1,1,4],
 "globals_k.html":[4,1,0,1],
-"globals_n.html":[4,1,0,2],
-"globals_s.html":[4,1,0,3],
+"globals_m.html":[4,1,0,2],
+"globals_n.html":[4,1,0,3],
+"globals_s.html":[4,1,0,4],
 "globals_type.html":[4,1,2],
 "group__callbacks_group.html":[2,1],
 "group__callbacks_group.html#ga245131e64f1d0dff7edc8ed874a07e9a":[2,1,10],
@@ -124,7 +128,7 @@ var NAVTREEINDEX0 =
 "group__conn_sub_group.html#ga96fa115fd5b2ef7658884da80714b91c":[2,2,9,2,4],
 "group__conn_sub_group.html#gacb2c83b58b7909715424cbc327fdd404":[2,2,9,2,1],
 "group__conn_sub_group.html#gaefab965b5645798d47f9244f2b3fe3fb":[2,2,9,2,0],
-"group__env_variables_group.html":[2,4],
+"group__env_variables_group.html":[2,5],
 "group__func_group.html":[2,2],
 "group__inbox_group.html":[2,2,6],
 "group__inbox_group.html#gaa1ec779a0b7ead54b78da05533848b6d":[2,2,6,0],
@@ -245,9 +249,5 @@ var NAVTREEINDEX0 =
 "group__kv_status.html#gaa747ad0a6182ec7a47fb47018c33d1c1":[2,2,14,3,3],
 "group__kv_status.html#gada6f22b5659b184762cea4f45d369ee5":[2,2,14,3,2],
 "group__kv_watcher.html":[2,2,14,2],
-"group__kv_watcher.html#ga21bc39fa795f7c4f392bd6d4e66ea1d9":[2,2,14,2,2],
-"group__kv_watcher.html#ga562c216a0199c30455af4c2da46000e5":[2,2,14,2,0],
-"group__kv_watcher.html#ga73adf44114fedd62ef75ebd81839b65e":[2,2,14,2,1],
-"group__libevent_functions.html":[2,5],
-"group__libevent_functions.html#ga195d269473332931fd0fede0bac3309e":[2,5,0]
+"group__kv_watcher.html#ga21bc39fa795f7c4f392bd6d4e66ea1d9":[2,2,14,2,2]
 };
