@@ -29,14 +29,16 @@ var searchData=
   ['jssequencepair_26',['jsSequencePair',['../structjs_sequence_pair.html',1,'']]],
   ['jsstreamalternate_27',['jsStreamAlternate',['../structjs_stream_alternate.html',1,'']]],
   ['jsstreamconfig_28',['jsStreamConfig',['../structjs_stream_config.html',1,'']]],
-  ['jsstreaminfo_29',['jsStreamInfo',['../structjs_stream_info.html',1,'']]],
-  ['jsstreaminfolist_30',['jsStreamInfoList',['../structjs_stream_info_list.html',1,'']]],
-  ['jsstreamnameslist_31',['jsStreamNamesList',['../structjs_stream_names_list.html',1,'']]],
-  ['jsstreamsource_32',['jsStreamSource',['../structjs_stream_source.html',1,'']]],
-  ['jsstreamsourceinfo_33',['jsStreamSourceInfo',['../structjs_stream_source_info.html',1,'']]],
-  ['jsstreamstate_34',['jsStreamState',['../structjs_stream_state.html',1,'']]],
-  ['jsstreamstatesubject_35',['jsStreamStateSubject',['../structjs_stream_state_subject.html',1,'']]],
-  ['jsstreamstatesubjects_36',['jsStreamStateSubjects',['../structjs_stream_state_subjects.html',1,'']]],
-  ['jssuboptions_37',['jsSubOptions',['../structjs_sub_options.html',1,'']]],
-  ['jstier_38',['jsTier',['../structjs_tier.html',1,'']]]
+  ['jsstreamconsumerlimits_29',['jsStreamConsumerLimits',['../structjs_stream_consumer_limits.html',1,'']]],
+  ['jsstreaminfo_30',['jsStreamInfo',['../structjs_stream_info.html',1,'']]],
+  ['jsstreaminfolist_31',['jsStreamInfoList',['../structjs_stream_info_list.html',1,'']]],
+  ['jsstreamnameslist_32',['jsStreamNamesList',['../structjs_stream_names_list.html',1,'']]],
+  ['jsstreamsource_33',['jsStreamSource',['../structjs_stream_source.html',1,'']]],
+  ['jsstreamsourceinfo_34',['jsStreamSourceInfo',['../structjs_stream_source_info.html',1,'']]],
+  ['jsstreamstate_35',['jsStreamState',['../structjs_stream_state.html',1,'']]],
+  ['jsstreamstatesubject_36',['jsStreamStateSubject',['../structjs_stream_state_subject.html',1,'']]],
+  ['jsstreamstatesubjects_37',['jsStreamStateSubjects',['../structjs_stream_state_subjects.html',1,'']]],
+  ['jssubjecttransformconfig_38',['jsSubjectTransformConfig',['../structjs_subject_transform_config.html',1,'']]],
+  ['jssuboptions_39',['jsSubOptions',['../structjs_sub_options.html',1,'']]],
+  ['jstier_40',['jsTier',['../structjs_tier.html',1,'']]]
 ];
