@@ -28,14 +28,16 @@ var searchData=
   ['jssequencepair_25',['jsSequencePair',['../group__types_group.html#ga39011d30b295759b7f6ca0a7539dff8f',1,'nats.h']]],
   ['jsstreamalternate_26',['jsStreamAlternate',['../group__types_group.html#ga22c26dd5dd31df7982130ef203ad3490',1,'nats.h']]],
   ['jsstreamconfig_27',['jsStreamConfig',['../group__types_group.html#ga26fd6a73df327ca3c271e46ddefc8acf',1,'nats.h']]],
-  ['jsstreaminfo_28',['jsStreamInfo',['../group__types_group.html#ga2629c9454996edf7914be36a9e44921b',1,'nats.h']]],
-  ['jsstreaminfolist_29',['jsStreamInfoList',['../group__types_group.html#ga1e54c2a1bc94834d1670875fc151f565',1,'nats.h']]],
-  ['jsstreamnameslist_30',['jsStreamNamesList',['../group__types_group.html#gaf4d31a4dc83b2805422beafb1f8fa000',1,'nats.h']]],
-  ['jsstreamsource_31',['jsStreamSource',['../group__types_group.html#gab4c43c87d81917aab748a50eee028449',1,'nats.h']]],
-  ['jsstreamsourceinfo_32',['jsStreamSourceInfo',['../group__types_group.html#gab2f33f57188a550f2f747d4f27bc24bd',1,'nats.h']]],
-  ['jsstreamstate_33',['jsStreamState',['../group__types_group.html#ga2bfd6de6ffc84d767482b3dd57cb9271',1,'nats.h']]],
-  ['jsstreamstatesubject_34',['jsStreamStateSubject',['../group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa',1,'nats.h']]],
-  ['jsstreamstatesubjects_35',['jsStreamStateSubjects',['../group__types_group.html#gae8b57d9c40364f97a705f3e61a1156b0',1,'nats.h']]],
-  ['jssuboptions_36',['jsSubOptions',['../group__types_group.html#gaccfaac2079656ffd40d003e4de5d2280',1,'nats.h']]],
-  ['jstier_37',['jsTier',['../group__types_group.html#ga1d48d3eb36b50c9ab6d8477dccf247d8',1,'nats.h']]]
+  ['jsstreamconsumerlimits_28',['jsStreamConsumerLimits',['../group__types_group.html#gadb76a02c18655461dbd3ee266502338c',1,'nats.h']]],
+  ['jsstreaminfo_29',['jsStreamInfo',['../group__types_group.html#ga2629c9454996edf7914be36a9e44921b',1,'nats.h']]],
+  ['jsstreaminfolist_30',['jsStreamInfoList',['../group__types_group.html#ga1e54c2a1bc94834d1670875fc151f565',1,'nats.h']]],
+  ['jsstreamnameslist_31',['jsStreamNamesList',['../group__types_group.html#gaf4d31a4dc83b2805422beafb1f8fa000',1,'nats.h']]],
+  ['jsstreamsource_32',['jsStreamSource',['../group__types_group.html#gab4c43c87d81917aab748a50eee028449',1,'nats.h']]],
+  ['jsstreamsourceinfo_33',['jsStreamSourceInfo',['../group__types_group.html#gab2f33f57188a550f2f747d4f27bc24bd',1,'nats.h']]],
+  ['jsstreamstate_34',['jsStreamState',['../group__types_group.html#ga2bfd6de6ffc84d767482b3dd57cb9271',1,'nats.h']]],
+  ['jsstreamstatesubject_35',['jsStreamStateSubject',['../group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa',1,'nats.h']]],
+  ['jsstreamstatesubjects_36',['jsStreamStateSubjects',['../group__types_group.html#gae8b57d9c40364f97a705f3e61a1156b0',1,'nats.h']]],
+  ['jssubjecttransformconfig_37',['jsSubjectTransformConfig',['../group__types_group.html#gac3148248f38749f6ba70471b7a6b96e1',1,'nats.h']]],
+  ['jssuboptions_38',['jsSubOptions',['../group__types_group.html#gaccfaac2079656ffd40d003e4de5d2280',1,'nats.h']]],
+  ['jstier_39',['jsTier',['../group__types_group.html#ga1d48d3eb36b50c9ab6d8477dccf247d8',1,'nats.h']]]
 ];
