@@ -5,8 +5,9 @@ var searchData=
   ['template_2',['Template',['../structjs_stream_config.html#a50f866f0e73c4ff0a5f43b354a059fa9',1,'jsStreamConfig']]],
   ['tiers_3',['Tiers',['../structjs_account_info.html#ab654d5c7456bb62df1808deb32a620fc',1,'jsAccountInfo']]],
   ['tierslen_4',['TiersLen',['../structjs_account_info.html#a21c14ca283400c684b18e61a534b6724',1,'jsAccountInfo']]],
-  ['timeout_5',['Timeout',['../structkv_watch_options.html#a56183d56585697d058c7eeb20bdddb66',1,'kvWatchOptions::Timeout()'],['../structkv_purge_options.html#a245c2def0f3aabe617219772cf7680a8',1,'kvPurgeOptions::Timeout()']]],
+  ['timeout_5',['timeout',['../structkv_watch_options.html#a56183d56585697d058c7eeb20bdddb66',1,'kvWatchOptions::Timeout'],['../structkv_purge_options.html#a245c2def0f3aabe617219772cf7680a8',1,'kvPurgeOptions::Timeout']]],
   ['timestamp_6',['Timestamp',['../structjs_msg_meta_data.html#abab9ed5600a3629ea6d6c78170d7d5e9',1,'jsMsgMetaData']]],
   ['total_7',['Total',['../structjs_a_p_i_stats.html#a1545170bebb347d0ea1254f51c3027cf',1,'jsAPIStats']]],
-  ['ttl_8',['TTL',['../structkv_config.html#ad2f5503e2f2522cb52e0ba1b86983dba',1,'kvConfig']]]
+  ['ttl_8',['TTL',['../structkv_config.html#ad2f5503e2f2522cb52e0ba1b86983dba',1,'kvConfig']]],
+  ['type_9',['type',['../structmicro__service__info__s.html#a47188c4f3a9cc6fdd1151dd59db4b1fe',1,'micro_service_info_s::Type'],['../structmicro__service__stats__s.html#af37a4da72bb1e1ad292dd1caa6a309a2',1,'micro_service_stats_s::Type']]]
 ];
