@@ -1,4 +1,4 @@
-// Copyright 2019 The NATS Authors
+// Copyright 2023 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -17,7 +17,7 @@
 #include <sodium.h>
 
 natsStatus
-natsCrypto_Init()
+natsCrypto_Init(void)
 {
     return ((sodium_init() == -1) ? NATS_ERR : NATS_OK);
 }
@@ -485,7 +485,7 @@ secure_memzero(void * const pnt, const size_t len)
 }
 
 natsStatus
-natsCrypto_Init()
+natsCrypto_Init(void)
 {
   return NATS_OK;
 }
