@@ -1246,6 +1246,7 @@ jsSub_free(jsSub *jsi)
     NATS_FREE(jsi->nxtMsgSubj);
     NATS_FREE(jsi->cmeta);
     NATS_FREE(jsi->fcReply);
+    NATS_FREE(jsi->psubj);
     js_destroyConsumerConfig(jsi->ocCfg);
     NATS_FREE(jsi);
 
@@ -1321,14 +1322,11 @@ jsSub_deleteConsumerAfterDrain(natsSubscription *sub)
     s = jsSub_deleteConsumer(sub);
     if (s != NATS_OK)
     {
+        char tmp[256];
         natsConn_Lock(nc);
-        if (nc->opts->asyncErrCb != NULL)
-        {
-            char tmp[256];
-            snprintf(tmp, sizeof(tmp), "failed to delete consumer '%s': %u (%s)",
-                    consumer, s, natsStatus_GetText(s));
-            natsAsyncCb_PostErrHandler(nc, sub, s, NATS_STRDUP(tmp));
-        }
+        snprintf(tmp, sizeof(tmp), "failed to delete consumer '%s': %u (%s)",
+                 consumer, s, natsStatus_GetText(s));
+        natsAsyncCb_PostErrHandler(nc, sub, s, NATS_STRDUP(tmp));
         natsConn_Unlock(nc);
     }
 
@@ -1698,7 +1696,7 @@ jsSub_scheduleFlowControlResponse(jsSub *jsi, const char *reply)
 }
 
 static natsStatus
-_checkMsg(natsMsg *msg, bool checkSts, bool *usrMsg, natsMsg *mhMsg)
+_checkMsg(natsMsg *msg, bool checkSts, bool *usrMsg, natsMsg *mhMsg, const char* reqSubj)
 {
     natsStatus  s    = NATS_OK;
     const char  *val = NULL;
@@ -1735,6 +1733,13 @@ _checkMsg(natsMsg *msg, bool checkSts, bool *usrMsg, natsMsg *mhMsg)
     if (strncmp(val, CTRL_STATUS, HDR_STATUS_LEN) == 0)
         return NATS_OK;
 
+    // Before checking for "errors", if the incoming status message is
+    // for a previous request (message's subject is not reqSubj), then
+    // simply return NATS_OK. The caller will destroy the message and
+    // proceed as if nothing was received.
+    if (strcmp(natsMsg_GetSubject(msg), reqSubj) != 0)
+        return NATS_OK;
+
     // 404 indicating that there are no messages.
     if (strncmp(val, NOT_FOUND_STATUS, HDR_STATUS_LEN) == 0)
         return NATS_NOT_FOUND;
@@ -1800,6 +1805,7 @@ _fetch(natsMsgList *list, natsSubscription *sub, jsFetchRequest *req, bool simpl
     bool            sendReq  = true;
     jsSub           *jsi     = NULL;
     natsMsg         *mhMsg   = NULL;
+    char            *reqSubj = NULL;
     bool            noWait;
 
     if (list == NULL)
@@ -1833,11 +1839,15 @@ _fetch(natsMsgList *list, natsSubscription *sub, jsFetchRequest *req, bool simpl
     }
     natsBuf_InitWithBackend(&buf, buffer, 0, sizeof(buffer));
     nc   = sub->conn;
-    rply = (const char*) sub->subject;
     subj = jsi->nxtMsgSubj;
     pmc  = (sub->msgList.msgs > 0);
     jsi->inFetch = true;
-    if (req->Heartbeat)
+    jsi->fetchID++;
+    if (nats_asprintf(&reqSubj, "%.*s%" PRIu64, (int) strlen(sub->subject)-1, sub->subject, jsi->fetchID) < 0)
+        s = nats_setDefaultError(NATS_NO_MEMORY);
+    else
+        rply = (const char*) reqSubj;
+    if ((s == NATS_OK) && req->Heartbeat)
     {
         int64_t hbi = req->Heartbeat / 1000000;
         sub->refs++;
@@ -1884,8 +1894,9 @@ _fetch(natsMsgList *list, natsSubscription *sub, jsFetchRequest *req, bool simpl
         }
         if (s == NATS_OK)
         {
-            // Here we care only about user messages.
-            s = _checkMsg(msg, false, &usrMsg, mhMsg);
+            // Here we care only about user messages. We don't need to pass
+            // the request subject since it is not even checked in this case.
+            s = _checkMsg(msg, false, &usrMsg, mhMsg, NULL);
             if ((s == NATS_OK) && usrMsg)
             {
                 msgs[count++] = msg;
@@ -1930,7 +1941,7 @@ _fetch(natsMsgList *list, natsSubscription *sub, jsFetchRequest *req, bool simpl
         IFOK(s, natsSub_nextMsg(&msg, sub, timeout, true));
         if (s == NATS_OK)
         {
-            s = _checkMsg(msg, true, &usrMsg, mhMsg);
+            s = _checkMsg(msg, true, &usrMsg, mhMsg, rply);
             if ((s == NATS_OK) && usrMsg)
             {
                 msgs[count++] = msg;
@@ -1980,6 +1991,8 @@ _fetch(natsMsgList *list, natsSubscription *sub, jsFetchRequest *req, bool simpl
         natsTimer_Stop(jsi->hbTimer);
     natsSub_Unlock(sub);
 
+    NATS_FREE(reqSubj);
+
     return NATS_UPDATE_ERR_STACK(s);
 }
 
@@ -2070,15 +2083,12 @@ _hbTimerFired(natsTimer *timer, void* closure)
     }
 
     natsConn_Lock(nc);
-    if (nc->opts->asyncErrCb != NULL)
-    {
-        // Even if we have called resetOrderedConsumer, we will post something
-        // to the async error callback, either "missed heartbeats", or the error
-        // that occurred trying to do the reset.
-        if (s == NATS_OK)
-            s = NATS_MISSED_HEARTBEAT;
-        natsAsyncCb_PostErrHandler(nc, sub, s, NULL);
-    }
+    // Even if we have called resetOrderedConsumer, we will post something
+    // to the async error callback, either "missed heartbeats", or the error
+    // that occurred trying to do the reset.
+    if (s == NATS_OK)
+        s = NATS_MISSED_HEARTBEAT;
+    natsAsyncCb_PostErrHandler(nc, sub, s, NULL);
     natsConn_Unlock(nc);
 }
 
@@ -2191,18 +2201,34 @@ _processConsInfo(const char **dlvSubject, jsConsumerInfo *info, jsConsumerConfig
     jsConsumerConfig    *ccfg        = info->Config;
     const char          *dg          = NULL;
     natsStatus          s            = NATS_OK;
+    bool                matches      = false;
+    int                 i;
 
     *dlvSubject = NULL;
 
     // Make sure this new subject matches or is a subset.
-    if (!nats_IsStringEmpty(subj)
-        && !nats_IsStringEmpty(ccfg->FilterSubject)
-        && (strcmp(subj, ccfg->FilterSubject) != 0))
+    if (!nats_IsStringEmpty(subj))
     {
-        return nats_setError(NATS_ERR, "subject '%s' does not match consumer filter subject '%s'",
-                             subj, ccfg->FilterSubject);
+        if (nats_IsStringEmpty(ccfg->FilterSubject) && (ccfg->FilterSubjectsLen == 0))
+        {
+            matches = true;
+        }
+        else if (!nats_IsStringEmpty(ccfg->FilterSubject) && nats_HasPrefix(subj, ccfg->FilterSubject))
+        {
+            matches = true;
+        }
+        else if (ccfg->FilterSubjectsLen > 0)
+        {
+            for (i = 0; (i < ccfg->FilterSubjectsLen) && !matches; i++)
+            {
+                matches = nats_HasPrefix(subj, ccfg->FilterSubjects[i]);
+            }
+        }
+        if (!matches)
+        {
+            return nats_setError(NATS_ERR, "subject '%s' does not match any consumer filter subjects.", subj);
+        }
     }
-
     // Check that if user wants to create a queue sub,
     // the consumer has no HB nor FC.
     queue = (nats_IsStringEmpty(queue) ? NULL : queue);
@@ -2531,6 +2557,8 @@ PROCESS_INFO:
                     s = nats_setDefaultError(NATS_NO_MEMORY);
             }
             IF_OK_DUP_STRING(s, jsi->stream, stream);
+            if ((s == NATS_OK) && !nats_IsStringEmpty(subject))
+                DUP_STRING(s, jsi->psubj, subject);
             if (s == NATS_OK)
             {
                 jsi->js     = js;
@@ -2561,10 +2589,19 @@ PROCESS_INFO:
     }
     if (s == NATS_OK)
     {
+        char *pullWCInbox = NULL;
+
         if (isPullMode)
         {
+            // Create a wildcard inbox.
             s = natsConn_newInbox(nc, &inbox);
-            deliver = (const char*) inbox;
+            if (s == NATS_OK)
+            {
+                if (nats_asprintf(&pullWCInbox, "%s.*", (const char*) inbox) < 0)
+                    s = nats_setDefaultError(NATS_NO_MEMORY);
+            }
+            if (s == NATS_OK)
+                deliver = (const char*) pullWCInbox;
         }
         // Create the NATS subscription on given deliver subject. Note that
         // cb/cbClosure will be NULL for sync or pull subscriptions.
@@ -2572,27 +2609,14 @@ PROCESS_INFO:
                                        opts->Queue, 0, cb, cbClosure, false, jsi));
         if ((s == NATS_OK) && (hbi > 0) && !isPullMode)
         {
-            // We will create a timer if we use create an ordered consumer, or
-            // if the async error callback is registered.
-            bool ct = opts->Ordered;
-
-            // Check to see if it is even worth creating a timer to check
-            // on missed heartbeats, since the way to notify the user will be
-            // through async callback.
-            natsConn_Lock(nc);
-            ct = ct || (nc->opts->asyncErrCb != NULL ? true : false);
-            natsConn_Unlock(nc);
-
-            if (ct)
-            {
-                natsSub_Lock(sub);
-                sub->refs++;
-                s = natsTimer_Create(&jsi->hbTimer, _hbTimerFired, _hbTimerStopped, hbi*2, (void*) sub);
-                if (s != NATS_OK)
-                    sub->refs--;
-                natsSub_Unlock(sub);
-            }
+            natsSub_Lock(sub);
+            sub->refs++;
+            s = natsTimer_Create(&jsi->hbTimer, _hbTimerFired, _hbTimerStopped, hbi*2, (void*) sub);
+            if (s != NATS_OK)
+                sub->refs--;
+            natsSub_Unlock(sub);
         }
+        NATS_FREE(pullWCInbox);
     }
     if ((s == NATS_OK) && create)
     {
@@ -2940,7 +2964,7 @@ natsMsg_isJSCtrl(natsMsg *msg, int *ctrlType)
     if (*p != ' ')
         return false;
 
-    while ((*p != '\0') && isspace(*p))
+    while ((*p != '\0') && isspace((unsigned char) *p))
         p++;
 
     if ((*p == '\r') || (*p == '\n') || (*p == '\0'))
@@ -2951,10 +2975,10 @@ natsMsg_isJSCtrl(natsMsg *msg, int *ctrlType)
 
     p += HDR_STATUS_LEN;
 
-    if (!isspace(*p))
+    if (!isspace((unsigned char) *p))
         return false;
 
-    while (isspace(*p))
+    while (isspace((unsigned char) *p))
         p++;
 
     if (strstr(p, "Idle") == p)
@@ -3061,17 +3085,13 @@ _recreateOrderedCons(void *closure)
     }
     if (s != NATS_OK)
     {
+        char tmp[256];
+        const char *lastErr = nats_GetLastError(NULL);
         natsConn_Lock(nc);
-        if (nc->opts->asyncErrCb != NULL)
-        {
-            char tmp[256];
-            const char *lastErr = nats_GetLastError(NULL);
-
-            snprintf(tmp, sizeof(tmp),
-                        "error recreating ordered consumer, will try again: status=%u error=%s",
-                        s, (nats_IsStringEmpty(lastErr) ? natsStatus_GetText(s) : lastErr));
-            natsAsyncCb_PostErrHandler(nc, sub, s, NATS_STRDUP(tmp));
-        }
+        snprintf(tmp, sizeof(tmp),
+                 "error recreating ordered consumer, will try again: status=%u error=%s",
+                 s, (nats_IsStringEmpty(lastErr) ? natsStatus_GetText(s) : lastErr));
+        natsAsyncCb_PostErrHandler(nc, sub, s, NATS_STRDUP(tmp));
         natsConn_Unlock(nc);
     }
 
