@@ -103,6 +103,17 @@
 #define MAX_FRAMES (50)
 
 #define nats_IsStringEmpty(s) ((((s) == NULL) || ((s)[0] == '\0')) ? true : false)
+#define nats_HasPrefix(_s, _prefix) (nats_IsStringEmpty(_s) ? nats_IsStringEmpty(_prefix) : (strncmp((_s), (_prefix), strlen(_prefix)) == 0))
+
+static inline bool nats_StringEquals(const char *s1, const char *s2)
+{
+    if (s1 == NULL)
+        return (s2 == NULL);
+    if (s2 == NULL)
+        return false;
+
+    return strcmp(s1, s2);
+}
 
 #define DUP_STRING(s, s1, s2) \
         { \
@@ -192,6 +203,7 @@ typedef struct __userCreds
 {
     char        *userOrChainedFile;
     char        *seedFile;
+    char        *jwtAndSeedContent;
 
 } userCreds;
 
@@ -246,6 +258,9 @@ struct __natsOptions
     natsErrHandler          asyncErrCb;
     void                    *asyncErrCbClosure;
 
+    natsConnectionHandler   microClosedCb;
+    natsErrHandler          microAsyncErrCb;
+
     int64_t                 pingInterval;
     int                     maxPingsOut;
     int                     maxPendingMsgs;
@@ -281,7 +296,7 @@ struct __natsOptions
     bool                    retryOnFailedConnect;
 
     // Callback/closure used to get the user JWT. Will be set to
-    // internal natsConn_userFromFile function when userCreds != NULL.
+    // internal natsConn_userCreds function when userCreds != NULL.
     natsUserJWTHandler      userJWTHandler;
     void                    *userJWTClosure;
 
@@ -294,8 +309,9 @@ struct __natsOptions
     // to the server.
     char                    *nkey;
 
-    // If user has invoked natsOptions_SetUserCredentialsFromFiles, this
-    // will be set and points to userOrChainedFile and possibly seedFile.
+    // If user has invoked natsOptions_SetUserCredentialsFromFiles or
+    // natsOptions_SetUserCredentialsFromMemory, this will be set and points to
+    // userOrChainedFile, seedFile, or possibly directly contains the JWT+seed content.
     struct __userCreds      *userCreds;
 
     // Reconnect jitter added to reconnect wait
@@ -311,6 +327,9 @@ struct __natsOptions
 
     // Custom inbox prefix
     char *inboxPfx;
+
+    // Custom message payload padding size
+    int payloadPaddingSize;
 };
 
 typedef struct __nats_MsgList
@@ -365,12 +384,14 @@ typedef struct __jsSub
     jsCtx               *js;
     char                *stream;
     char                *consumer;
+    char                *psubj;
     char                *nxtMsgSubj;
     bool                pull;
     bool                inFetch;
     bool                ordered;
     bool                dc; // delete JS consumer in Unsub()/Drain()
     bool                ackNone;
+    uint64_t            fetchID;
 
     // This is ConsumerInfo's Pending+Consumer.Delivered that we get from the
     // add consumer response. Note that some versions of the server gather the
@@ -786,6 +807,18 @@ natsLib_getMsgDeliveryPoolInfo(int *maxSize, int *size, int *idx, natsMsgDlvWork
 void
 nats_setNATSThreadKey(void);
 
+natsStatus
+natsLib_startServiceCallbacks(microService *m);
+
+void
+natsLib_stopServiceCallbacks(microService *m);
+
+natsMutex*
+natsLib_getServiceCallbackMutex(void);
+
+natsHash*
+natsLib_getAllServicesToCallback(void);
+
 //
 // Threads
 //
